<?php

/**
 * @file
 * Administration functions for the Trebutra module.
 */

/**
 * Form constructor for the admin settings form.
 */
function trebutra_settings_form($form, &$form_state) {
  $form['trebutra_api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Trello API Key'),
    '#default_value' => variable_get('trebutra_api_key', ''),
    '#description' => t('Please click <a href="https://trello.com/app-key" target="_blank">here</a> to get your key.'),
  );
  if(!empty(variable_get('trebutra_api_key'))) {
    $form['trebutra_token'] = array(
      '#type' => 'textfield',
      '#title' => t('Trello API token'),
      '#default_value' => variable_get('trebutra_token', ''),
      '#description' => t('Click "Generate Token" to retrieve your token.'),
    );
    if(!empty(variable_get('trebutra_token'))) {
      $form['actions']['retrieve_boards'] = array(
        '#type' => 'submit',
        '#value' => t('Sync Boards & Lists'),
        '#submit' => array('trebutra_retrieve_boards'),
      );
      if(!empty(variable_get('trebutra_boards'))) {
        $form['trebutra_listid'] = array(
          '#type' => 'select',
          '#title' => t('Trello Boards'),
          '#options' => variable_get('trebutra_boards', array('error'=>'error: could not retrieve any boards')),
          '#description' => t('Select the board and list you\'d like bugs posted to.'),
          '#default_value' => variable_get('trebutra_listid', ''),
        );
        $form['trebutra_email'] = array(
          '#type' => 'textfield',
          '#title' => t('Report recipient email'),
          '#default_value' => variable_get('trebutra_email', ''),
          '#description' => t('If you would like to receive bug reports, enter an email here.'),
        );
      }
    } else {
      $form['#attached']['js'] = array(drupal_get_path('module', 'trebutra') . '/trebutra.js' => array('type' => 'file', 'scope' => 'footer'));
    }
    $form['actions']['get_token'] = array(
      '#type' => 'submit',
      '#value' => t('Generate Token'),
      '#submit' => array('trebutra_get_token'),
    );
  }
  $form['#submit'][] = 'trebutra_settings_form_submit';


  return system_settings_form($form);
}

function trebutra_settings_form_submit($form, &$form_state) {
  if(empty(variable_get('trebutra_api_key'))) {
    drupal_set_message('Great, now you can generate a token.');
  } else {
    if(!empty(variable_get('trebutra_boards'))) {
      drupal_set_message('Success! You\'re ready to go.');
    } else {
      drupal_set_message('Success! Now, retrieve your board lists by clicking "Sync Boards & Lists". If you have a lot of boards - and a lot of lists and cards - this may take several minutes, please be patient.');
    }
  }
}

function trebutra_retrieve_boards($form, &$form_state) {
  if(variable_get('trebutra_token')) {
    $token = variable_get('trebutra_token');
    $key = variable_get('trebutra_api_key');
    $json_results = file_get_contents('https://trello.com/1/members/me/boards?fields=name&key='.$key.'&token='.$token);

    $results = json_decode($json_results);

    foreach($results as $result) {
      $lists = json_decode(file_get_contents('https://api.trello.com/1/boards/'.$result->id.'/lists?cards=open&card_fields=name&fields=name&key='.$key.'&token='.$token));
      foreach($lists as $list) {
        $boards[$list->id] = $result->name.": ".$list->name;
      }
    }

    if(!empty($boards)) {
      variable_set('trebutra_boards', $boards);
    }
  }
}

function trebutra_get_token($form, &$form_state) {
  $key = variable_get('trebutra_api_key');
  drupal_set_message('WARNING: You MUST press "Save Configuration" before continuing.', 'warning');
  drupal_set_message('If you see the token filled out below, you were successful. If not, you will need to get the token yourself, paste it below and click "Save Configuration". Retrieve it here: https://trello.com/1/connect?key='.$key.'&name=Trebutra&response_type=token&scope=read,write&expiration=never');
  $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
  $site_url = $protocol . $_SERVER['HTTP_HOST'] . request_uri();
  $trello_key = $form_state['values']['trebutra_key'];
  $url = "https://trello.com/1/connect?key='.$key.'&name=Trebutra&response_type=token&scope=read,write&expiration=never&return_url=".$site_url;
  drupal_goto($url, array('external' => TRUE));
}
